@@ -13,17 +13,11 @@ DOCUMENTATION = """
 module: hv_truecopy
 short_description: Manages TrueCopy pairs on Hitachi VSP storage systems.
 description:
-  - This module allows for the creation, deletion, splitting, re-syncing and resizing of TrueCopy pairs for
-    both C(direct) and C(gateway) connection types on Hitachi VSP storage systems.
-  - It also allows swap-splitting and swap-resyncing operations of TrueCopy pairs for C(direct) connection type
-    on Hitachi VSP storage systems.
-  - It supports various TrueCopy pairs operations based on the specified task level.
-  - This module is supported for both C(direct) and C(gateway) connection types.
-  - swap_split and swap_resync are supported for C(direct) connection type only.
-  - For C(direct) connection type examples, go to URL
+  - This module allows for the creation, deletion, splitting, re-syncing and resizing of TrueCopy pairs.
+  - It also allows swap-splitting and swap-resyncing operations of TrueCopy pairs.
+  - It supports various TrueCopy pairs operations based on the specified task level..
+  - For examples, go to URL
     U(https://github.com/hitachi-vantara/vspone-block-ansible/blob/main/playbooks/vsp_direct/truecopy.yml)
-  - For C(gateway) connection type examples, go to URL
-    U(https://github.com/hitachi-vantara/vspone-block-ansible/blob/main/playbooks/vsp_uai_gateway/truecopy.yml)
 version_added: '3.1.0'
 author:
   - Hitachi Vantara LTD (@hitachi-vantara)
@@ -33,6 +27,13 @@ attributes:
   check_mode:
     description: Determines if the module should run in check mode.
     support: none
+extends_documentation_fragment:
+- hitachivantara.vspone_block.common.gateway_note
+notes:
+  - The input parameters C(allocate_new_consistency_group), C(begin_secondary_volume_id) and C(end_secondary_volume_id) were removed in version 3.4.0.
+    They were deprecated due to internal API simplification and are no longer supported.
+  - The output parameters C(entitlement_status), C(subscriber_id), and C(partner_id) were removed in version 3.4.0.
+    They were also deprecated due to internal API simplification and are no longer supported.
 options:
   state:
     description:
@@ -42,25 +43,23 @@ options:
       - C(expand) or C(resize) is used to expand the size of the volumes of a TrueCopy pair.
       - C(resync) is used to re-sync a TrueCopy pair.
       - C(split) is used to split a TrueCopy pair.
-      - C(swap-split) is used to swap-split a TrueCopy pair. Supported for C(direct) connection type only.
-      - C(swap-resync) is used to swap-resync a TrueCopy pair. Supported for C(direct) connection only.
+      - C(swap-split) is used to swap-split a TrueCopy pair.
+      - C(swap-resync) is used to swap-resync a TrueCopy pair.
     type: str
     required: false
     choices: ['present', 'absent', 'split', 'resync', 'resize', 'expand', 'swap_split', 'swap_resync']
     default: 'present'
   storage_system_info:
-    description:
-      - Information about the Hitachi storage system. This field is required for gateway connection type only.
+    description: Information about the storage system. This field is an optional field.
     type: dict
     required: false
     suboptions:
       serial:
-        description: Serial number of the Hitachi storage system.
+        description: The serial number of the storage system.
         type: str
         required: false
   secondary_connection_info:
     description: Information required to establish a connection to the secondary storage system.
-        Required for C(direct) connection type only. Not needed for C(gateway) connection type.
     required: false
     type: dict
     suboptions:
@@ -70,11 +69,11 @@ options:
         type: str
         required: true
       username:
-        description: Username for authentication. This field is valid for C(direct) connection type only, and it is a required field.
+        description: Username for authentication. This is a required field.
         type: str
         required: false
       password:
-        description: Password for authentication. This field is valid for C(direct) connection type only, and it is a required field.
+        description: Password for authentication. This is a required field.
         type: str
         required: false
       api_token:
@@ -83,89 +82,71 @@ options:
         required: false
   connection_info:
     description: Information required to establish a connection to the storage system.
-    required: true
     type: dict
+    required: true
     suboptions:
       address:
-        description: IP address or hostname of either the UAI gateway or Hitachi storage system.
+        description: IP address or hostname of the storage system.
         type: str
         required: true
       username:
-        description: Username for authentication. Required for C(direct) connection type. Not needed for C(gateway) connection type as it uses API token.
+        description: Username for authentication. This is a required field.
         type: str
         required: false
       password:
-        description: Password for authentication. Required for C(direct) connection. Not needed for C(gateway) connection type as it uses API token.
-        type: str
-        required: false
-      connection_type:
-        description: Type of connection to the storage system. Two types of connections are supported, C(direct) and C(gateway).
-        type: str
-        required: false
-        choices: ['gateway', 'direct']
-        default: 'direct'
-      subscriber_id:
-        description: Subscriber ID is required for C(gateway) connection type to support multi-tenancy. Not needed for C(direct) connection type
-          or for C(gateway) connection type with single tenant.
+        description: Password for authentication. This is a required field.
         type: str
         required: false
       api_token:
-        description: Token value to access UAI gateway for C(gateway) connection type. This is a required field for C(gateway) connection type.
-          This field is used for C(direct) connection type to pass the value of the lock token to operate on locked resources.
+        description: This field is used to pass the value of the lock token to operate on locked resources.
         type: str
         required: false
+      connection_type:
+        description: Type of connection to the storage system.
+        type: str
+        required: false
+        choices: ['direct']
+        default: 'direct'
   spec:
     description: Specification for the TrueCopy pairs task.
     type: dict
     required: false
     suboptions:
       copy_group_name:
-        description: Name of the copy group. This field is used only for C(direct) connection type. This is a required field for create operation.
+        description: Name of the copy group. This is a required field for create operation.
           For other operations, this field is optional, but when provided, the time to complete the operation is faster.
         type: str
         required: false
       copy_pair_name:
-        description: Name of the copy pair. This field is used only for C(direct) connection type. This is a required field for create operation.
+        description: Name of the copy pair. This is a required field for create operation.
           For other operations, this field is optional, but when provided, the time to complete the operation is faster.
         type: str
         required: false
       remote_device_group_name:
-        description: Name of the remote device group. This field is used only for C(direct) connection type. This is an optional field.
+        description: Name of the remote device group. This is an optional field.
         type: str
         required: false
       local_device_group_name:
-        description: Name of the local device group. This field is used only for C(direct) connection type. This is an optional field.
+        description: Name of the local device group. This is an optional field.
         type: str
         required: false
       primary_volume_id:
-        description: Primary volume ID. This is a required field for create operation for both C(direct) and C(gateway) connection types.
+        description: Primary volume ID. This is a required field for create operation.
         type: int
         required: false
       consistency_group_id:
-        description: Consistency Group ID, 0 to 255. This is an optional field for both C(direct) and C(gateway) connection types.
+        description: Consistency Group ID, 0 to 255. This is an optional field.
         type: int
         required: false
       fence_level:
         description: Specifies the primary volume fence level setting and determines if the host is denied access or continues to access
-            the primary volume when the pair is suspended because of an error. This is an optional field for both C(direct) and C(gateway)
-            connection types.
+            the primary volume when the pair is suspended because of an error. This is an optional field.
         type: str
         required: false
         choices: ['NEVER', 'DATA', 'STATUS']
         default: 'NEVER'
-      allocate_new_consistency_group:
-        description: Allocate and assign a new consistency group ID, cannot be true if consistency_group_id is specified.
-          This is used only for C(gateway) connection type and is an optional field.
-        type: bool
-        required: false
-        default: false
-      secondary_storage_serial_number:
-        description: Secondary storage serial number. This is used only for C(gateway) connection type and required for create.
-        type: int
-        required: false
       secondary_pool_id:
-        description: ID of the dynamic pool where the secondary volume will be created. This is required for create operation
-            for both C(direct) and C(gateway) connection types.
+        description: ID of the dynamic pool where the secondary volume will be created.
         type: int
         required: false
       copy_pace:
@@ -183,22 +164,42 @@ options:
         required: false
         suboptions:
           name:
-            description: Name of the host group on the secondary storage system. This is required for create operation for
-                both C(direct) and C(gateway) connection types.
+            description: Name of the host group on the secondary storage system. This is required for create operation.
             type: str
             required: true
           port:
-            description: Port of the host group on the secondary storage system. This is required for create operation for
-                both C(direct) and C(gateway) connection types.
+            description: Port of the host group on the secondary storage system. This is required for create operation.
             type: str
             required: true
+          lun_id:
+            description: LUN ID of the host group on the secondary storage system. This is not required for create operation.
+            type: int
+            required: false
+      secondary_iscsi_targets:
+        description: The list of iscsi targets on the secondary storage device.
+        type: list
+        elements: dict
+        required: false
+        suboptions:
+          name:
+            description: ISCSI target name.
+            type: str
+            required: true
+          port:
+            description: Port name.
+            type: str
+            required: true
+          lun_id:
+            description: LUN ID.
+            type: int
+            required: false
       secondary_nvm_subsystem:
-        description: NVM subsystem details of the secondary volume. Supported only for C(direct) connection type.
+        description: NVM subsystem details of the secondary volume.
         type: dict
         required: false
         suboptions:
           name:
-            description: Name of the NVM subsystem on the secondary storage system.
+            description: Name of the NVM subsytem on the secondary storage system.
             type: str
             required: true
           paths:
@@ -207,31 +208,29 @@ options:
             elements: str
             required: false
       do_initial_copy:
-        description: Perform initial copy. This is used only for C(direct) connection type and is an optional field during create operation.
+        description: Perform initial copy. This is an optional field during create operation.
         type: bool
         required: false
         default: true
       is_data_reduction_force_copy:
-        description: Force copy for data reduction. This is used for both C(direct) and C(gateway) connection types and is an
-          optional field during create operation.
+        description: Force copy for data reduction. This is an optional field during create operation.
         type: bool
         required: false
         default: false
       is_new_group_creation:
-        description: Create a new copy group. This is used only for C(direct) connection type and is an optional field during create operation.
+        description: Create a new copy group. This is an optional field during create operation.
         type: bool
         required: false
         default: false
       path_group_id:
         description: >
-          This is used only for C(direct) connection type and is an optional field during create operation.
+          This is an optional field during create operation.
           Specify the path group ID in the range from 0 to 255. If you are unsure don't use this parameter.
           If you omit this value or specify 0, the lowest path group ID in the specified path group is used.
         type: int
         required: false
       new_volume_size:
-        description: Required only for resize or expand operation for both C(direct) and C(gateway) connections types. Value should be grater than
-          the current volume size.
+        description: Required only for resize or expand operation. Value should be grater than the current volume size.
         type: str
         required: false
       secondary_volume_id:
@@ -240,85 +239,21 @@ options:
         required: false
       is_consistency_group:
         description: >
-          This is used only for C(direct) connection type and is an optional field during create operation.
+          This is an optional field during create operation.
           Depending on the value, this attribute specifies whether to register the new pair in a consistency group.
           If true, the new pair is registered in a consistency group. If false, the new pair is not registered in a consistency group.
         type: bool
         required: false
         default: false
-      begin_secondary_volume_id:
-        description: >
-          Specify beginning ldev id for Ldev range for svol. This is used only for C(gateway) connection type and is an optional field during
-          create operation. If this field is specified, end_secondary_volume_id must also be specified.
-          If this field is not specified, Ansible modules will try to create SVOL ID same as (or near to ) PVOL ID.
+      should_delete_svol:
+        description: Specify true to delete the SVOL.
+        type: bool
         required: false
-        type: int
-      end_secondary_volume_id:
-        description: >
-          Specify end ldev id for Ldev range for svol. This is used only for C(gateway) connection type and is an optional field during create operation.
-          If this field is specified, begin_secondary_volume_id must also be specified.
-          If this field is not specified, Ansible modules will try to create SVOL ID same as (or near to ) PVOL ID.
-        required: false
-        type: int
+        default: false
 """
 
 EXAMPLES = """
-- name: Create a TrueCopy pair for gateway connection type
-  hitachivantara.vspone_block.vsp.hv_truecopy:
-    state: "present"
-    storage_system_info:
-      serial: 811150
-    connection_info:
-      address: gateway.company.com
-      api_token: "api_token_value"
-      connection_type: "gateway"
-      subscriber_id: 123456
-    spec:
-      primary_volume_id: 11
-      consistency_group_id: -1
-      fence_level: 'NEVER'
-      allocate_new_consistency_group: false
-      secondary_storage_serial_number: 811145
-      secondary_pool_id: 1
-
-- name: Split a TrueCopy pair for gateway connection type
-  hitachivantara.vspone_block.vsp.hv_truecopy:
-    state: "split"
-    storage_system_info:
-      serial: 811150
-    connection_info:
-      address: gateway.company.com
-      api_token: "api_token_value"
-      connection_type: "gateway"
-      subscriber_id: 123456
-    spec:
-      primary_volume_id: 11
-
-- name: Resync a TrueCopy pair for gateway connection type
-  hitachivantara.vspone_block.vsp.hv_truecopy:
-    state: "resync"
-    storage_system_info:
-      serial: 811150
-    connection_info:
-      address: gateway.company.com
-      api_token: "api_token_value"
-      connection_type: "gateway"
-      subscriber_id: 123456
-    spec:
-      primary_volume_id: 11
-
-- name: Delete a TrueCopy pair for gateway connection type
-  hitachivantara.vspone_block.vsp.hv_truecopy:
-    state: "absent"
-    connection_info:
-      address: gateway.company.com
-      api_token: "api_token_value"
-      connection_type: "gateway"
-      subscriber_id: 123456
-    spec:
-      primary_volume_id: 11
-
-- name: Create a TrueCopy pair for direct connection type
+- name: Create a TrueCopy pair
   hitachivantara.vspone_block.vsp.hv_truecopy:
     state: "present"
     connection_info:
@@ -339,8 +274,9 @@ EXAMPLES = """
       secondary_hostgroup:
         name: ansible_test_group
         port: CL1-A
+        lun_id: 1
 
-- name: Split a TrueCopy pair for direct connection type
+- name: Split a TrueCopy pair
   hitachivantara.vspone_block.vsp.hv_truecopy:
     state: "split"
     connection_info:
@@ -355,7 +291,7 @@ EXAMPLES = """
       copy_group_name: "copy_group_name_1"
       copy_pair_name: "copy_pair_name_1"
 
-- name: Resync a TrueCopy pair for direct connection type
+- name: Resync a TrueCopy pair
   hitachivantara.vspone_block.vsp.hv_truecopy:
     state: "resync"
     connection_info:
@@ -370,7 +306,7 @@ EXAMPLES = """
       copy_group_name: "copy_group_name_1"
       copy_pair_name: "copy_pair_name_1"
 
-- name: Swap-split a TrueCopy pair for direct connection type
+- name: Swap-split a TrueCopy pair
   hitachivantara.vspone_block.vsp.hv_truecopy:
     state: "swap_split"
     connection_info:
@@ -385,7 +321,7 @@ EXAMPLES = """
       copy_group_name: "copy_group_name_1"
       copy_pair_name: "copy_pair_name_1"
 
-- name: Swap-resync a TrueCopy pair for direct connection type
+- name: Swap-resync a TrueCopy pair
   hitachivantara.vspone_block.vsp.hv_truecopy:
     state: "swap_resync"
     connection_info:
@@ -400,7 +336,7 @@ EXAMPLES = """
       copy_group_name: "copy_group_name_1"
       copy_pair_name: "copy_pair_name_1"
 
-- name: Delete a TrueCopy pair for direct connection type
+- name: Delete a TrueCopy pair
   hitachivantara.vspone_block.vsp.hv_truecopy:
     state: "swap_resync"
     connection_info:
@@ -415,7 +351,7 @@ EXAMPLES = """
       copy_group_name: "copy_group_name_1"
       copy_pair_name: "copy_pair_name_1"
 
-- name: Increase the size of the volumes of a TrueCopy pair for direct connection type
+- name: Increase the size of the volumes of a TrueCopy pair
   hitachivantara.vspone_block.vsp.hv_truecopy:
     state: "expand"
     connection_info:
@@ -454,18 +390,10 @@ data:
       description: Copy progress rate.
       type: int
       sample: -1
-    entitlement_status:
-      description: Entitlement status.
-      type: str
-      sample: ""
     fence_level:
       description: Fence level.
       type: str
       sample: "NEVER"
-    partner_id:
-      description: Partner ID.
-      type: str
-      sample: ""
     primary_hex_volume_id:
       description: Primary hex volume ID.
       type: str
@@ -506,10 +434,6 @@ data:
       description: Storage serial number.
       type: str
       sample: "810050"
-    subscriber_id:
-      description: Subscriber ID.
-      type: str
-      sample: ""
     svol_access_mode:
       description: SVOL access mode.
       type: str
@@ -530,9 +454,6 @@ from ansible_collections.hitachivantara.vspone_block.plugins.module_utils.common
     VSPTrueCopyArguments,
     VSPParametersManager,
 )
-from ansible_collections.hitachivantara.vspone_block.plugins.module_utils.common.hv_constants import (
-    ConnectionTypes,
-)
 from ansible_collections.hitachivantara.vspone_block.plugins.module_utils.reconciler.vsp_true_copy import (
     VSPTrueCopyReconciler,
 )
@@ -545,9 +466,6 @@ from ansible_collections.hitachivantara.vspone_block.plugins.module_utils.common
 from ansible_collections.hitachivantara.vspone_block.plugins.module_utils.common.ansible_common import (
     validate_ansible_product_registration,
 )
-from ansible_collections.hitachivantara.vspone_block.plugins.module_utils.message.module_msgs import (
-    ModuleMessage,
-)
 
 
 @LogDecorator.debug_methods
@@ -616,14 +534,6 @@ class VSPSTrueCopyManager:
             self.state,
             self.secondary_connection_info,
         )
-        if self.connection_info.connection_type.lower() == ConnectionTypes.GATEWAY:
-            found = reconciler.check_storage_in_ucpsystem()
-            if not found:
-                raise ValueError(ModuleMessage.STORAGE_SYSTEM_ONBOARDING.value)
-            oob = reconciler.is_out_of_band()
-            self.logger.writeDebug(f"oob = {oob}")
-            if oob is True:
-                raise ValueError(ModuleMessage.OOB_NOT_SUPPORTED.value)
         return reconciler.reconcile_true_copy(self.spec)
 
     def get_message(self):
@@ -631,7 +541,10 @@ class VSPSTrueCopyManager:
         if self.state == "present":
             return "TrueCopy Pair created successfully."
         elif self.state == "absent":
-            return "TrueCopy Pair deleted successfully."
+            if self.spec.should_delete_svol is True:
+                return "TrueCopy Pair and Secondary volume deleted successfully."
+            else:
+                return "TrueCopy Pair deleted successfully."
         elif self.state == "resize" or self.state == "expand":
             return "TrueCopy Pair expanded successfully."
         elif self.state == "resync":
